import lorem
from anthropic import Anthropic, AsyncAnthropic
from typing import Any, Dict, AsyncGenerator, Union

class AnthropicMockWrapper:
    def __init__(self, client: Union[Anthropic, AsyncAnthropic]):
        self.client = client
        self.is_test = isinstance(client, Anthropic) and client.api_key.startswith("TEST_")

    async def completion(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
        if self.is_test:
            return self._get_mock_response(kwargs.get("max_tokens_to_sample", 100))
        
        if isinstance(self.client, AsyncAnthropic):
            return await self.client.completions.create(*args, **kwargs)
        else:
            return self.client.completions.create(*args, **kwargs)

    async def completion_stream(self, *args: Any, **kwargs: Any) -> AsyncGenerator[Dict[str, Any], None]:
        if self.is_test:
            yield self._get_mock_response(kwargs.get("max_tokens_to_sample", 100))
        else:
            if isinstance(self.client, AsyncAnthropic):
                async for chunk in self.client.completions.create(*args, **kwargs):
                    yield chunk
            else:
                for chunk in self.client.completions.create(*args, **kwargs):
                    yield chunk

    async def messages_create(self, *args: Any, **kwargs: Any) -> Dict[str, Any]:
        if self.is_test:
            return self._get_mock_response(kwargs.get("max_tokens", 100))
        
        return await self.client.messages.create(*args, **kwargs)


    def _get_mock_response(self, max_tokens: int) -> Dict[str, Any]:
        return {
            "completion": self._generate_lorem_ipsum(max_tokens),
            "stop_reason": "length",
            "model": "claude-2"
        }
    def _generate_lorem_ipsum(self, max_tokens: int) -> str:
        words = lorem.text().split()
        return " ".join(words[:max_tokens])



from setuptools import setup, find_packages

setup(
    name="anthropic_mock_wrapper",
    version="0.2.2",  # Increment the version number
    packages=find_packages(),
    install_requires=[
        "anthropic",
        "lorem",
    ],
    extras_require={
        "dev": [
            "mypy",
            "pytest",
            "pytest-asyncio",
        ]
    },
    author="Anurag Angara",
    author_email="anurag.angara@gmail.com",
    description="A lightweight wrapper around the Anthropic Python client for testing purposes",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/ps2-controller/anthropic_mock_wrapper",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)